@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.logger/src/logd.c,v 1.43 2011/10/25 13:32:14 zsustr Exp $"
+#ident "$Header: /cvs/glite/org.glite.lb.logger/src/logd.c,v 1.46 2013/01/31 16:31:23 mvocu Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -48,11 +48,11 @@ limitations under the License.
 #include "glite/lb/lb_perftest.h"
 #endif
 
-#define DEFAULT_PIDFILE "/var/glite/glite-lb-logd.pid"
+#define DEFAULT_PIDFILE "/var/run/glite/glite-lb-logd.pid"
 
 typedef void (*logd_handler_t)(int);
 
-static const char rcsid[] = "@(#)$Id: logd.c,v 1.43 2011/10/25 13:32:14 zsustr Exp $";
+static const char rcsid[] = "@(#)$Id: logd.c,v 1.46 2013/01/31 16:31:23 mvocu Exp $";
 static int debug = 0;
 static int port = EDG_WLL_LOG_PORT_DEFAULT;
 static char *prefix = EDG_WLL_LOG_PREFIX_DEFAULT;
@@ -64,8 +64,7 @@ static int noAuth = 0;
 static int noIPC = 0;
 static int noParse = 0;
 
-#define DEFAULT_SOCKET "/tmp/interlogger.sock"
-char *socket_path = DEFAULT_SOCKET;
+char *socket_path = EDG_WLL_LOG_SOCKET_DEFAULT;
 
 extern int confirm_sock;
 extern char confirm_sock_name[256];
@@ -461,7 +460,7 @@ This is LocalLogger, part of Workload Management System in EU DataGrid & EGEE.\n
    if (ret < 0)
    	glite_common_log(LOG_CATEGORY_SECURITY,LOG_PRIORITY_WARN,"edg_wll_gss_watch_creds failed, unable to access credentials\n");
    /* XXX DK: support noAuth */
-   ret = edg_wll_gss_acquire_cred_gsi(cert_file, key_file, &cred, &gss_stat);
+   ret = edg_wll_gss_acquire_cred(cert_file, key_file, GSS_C_ACCEPT, &cred, &gss_stat);
    if (ret) {
 	/* XXX DK: call edg_wll_gss_get_error() */
 	glite_common_log(LOG_CATEGORY_CONTROL,LOG_PRIORITY_FATAL,"Failed to get GSI credentials. Exiting.\n");
@@ -585,7 +584,7 @@ This is LocalLogger, part of Workload Management System in EU DataGrid & EGEE.\n
 	edg_wll_GssCred newcred;
 	case 0: break;
 	case 1:
-		ret = edg_wll_gss_acquire_cred_gsi(cert_file,key_file,&newcred,&gss_stat);
+		ret = edg_wll_gss_acquire_cred(cert_file,key_file, GSS_C_ACCEPT, &newcred,&gss_stat);
 		if (ret) {
 			glite_common_log(LOG_CATEGORY_SECURITY,LOG_PRIORITY_WARN,"Reloading credentials failed, continue with older\n");
 		} else {
